==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/PasswordAuthentication.java <==
/*
 * PasswordAuthentication.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * The class PasswordAuthentication is a data holder that is used by
 * Authenticator.
 * It is simply a repository for a user name and a password.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public final class PasswordAuthentication
{

  /*
   * The user name.
   */
  private String userName;

  /*
   * The password.
   */
  private String password;

  /**
   * Initialize a new PasswordAuthentication
   * @param userName the user name
   * @param password The user's password
   */
  public PasswordAuthentication(String userName, String password)
  {
    this.userName = userName;
    this.password = password;
  }

  /**
   * @return the user name
   */
  public String getUserName()
  {
    return userName;
  }

  /**
   * @return the password
   */
  public String getPassword()
  {
    return password;
  }
}

==> mail-1.1.tar.gz: mail-1.1/source/javax/mail/PasswordAuthentication.java <==
/*
 * PasswordAuthentication.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * Container for a username/password combination.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public final class PasswordAuthentication
{

  /*
   * The username.
   */
  private String userName;

  /*
   * The password.
   */
  private String password;

  /**
   * Creates a new password authentication
   * @param userName the username
   * @param password the password
   */
  public PasswordAuthentication(String userName, String password)
  {
    this.userName = userName;
    this.password = password;
  }

  /**
   * Returns the username.
   */
  public String getUserName()
  {
    return userName;
  }

  /**
   * Returns the password.
   */
  public String getPassword()
  {
    return password;
  }
  
}
